@@ -9,4 +9,4 @@ from asconnect.client import Client
 from asconnect.models import App
 from asconnect.models import Build
 
-from asconnect.itms import upload_build
+from asconnect.altool import Platform
